pub struct Entry {Show 20 fields
pub dump_id: i32,
pub had_dumper: bool,
pub table_oid: String,
pub oid: String,
pub tag: Option<String>,
pub desc: ObjectType,
pub section: Section,
pub defn: Option<String>,
pub drop_stmt: Option<String>,
pub copy_stmt: Option<String>,
pub namespace: Option<String>,
pub tablespace: Option<String>,
pub tableam: Option<String>,
pub relkind: Option<char>,
pub owner: Option<String>,
pub with_oids: bool,
pub dependencies: Vec<i32>,
pub data_state: OffsetState,
pub offset: u64,
pub filename: Option<String>,
}Fields
dump_id: i32had_dumper: booltable_oid: Stringoid: Stringtag: Option<String>desc: ObjectTypesection: Sectiondefn: Option<String>drop_stmt: Option<String>copy_stmt: Option<String>namespace: Option<String>tablespace: Option<String>tableam: Option<String>relkind: Option<char>owner: Option<String>with_oids: booldependencies: Vec<i32>data_state: OffsetStateCustom format: offset state (set, not set, no data).
offset: u64Custom format: byte offset of this entry’s data in the archive file.
filename: Option<String>Directory/tar format: relative filename for this entry’s data file.
Implementations
Sourceimpl Entry
impl Entry
Sourcepub fn computed_section(&self) -> Section
pub fn computed_section(&self) -> Section
Computes the section from the object type.
This is a derived value and may differ from Entry::section, which
holds the section as read from the archive file.